@@ -37,7 +37,7 @@ GIRepository.Repository.prepend_search_path('libgd')
 from gi.repository import Gtk, Gdk, GLib, Gio, GObject, Gst, GstAudio, GstPbutils
 from gettext import gettext as _
 from random import randint
-from queue import LifoQueue
+from collections import deque
 from gnomemusic.albumArtCache import AlbumArtCache
 from gnomemusic.playlists import Playlists
 playlists = Playlists.get_default()
@@ -71,7 +71,7 @@ class DiscoveryStatus:
 class Player(GObject.GObject):
     nextTrack = None
     timeout = None
-    shuffleHistory = LifoQueue(maxsize=10)
+    shuffleHistory = deque(maxlen=10)
 
     __gsignals__ = {
         'playing-changed': (GObject.SIGNAL_RUN_FIRST, None, ()),
@@ -217,8 +217,9 @@ class Player(GObject.GObject):
     def _onBusError(self, bus, message):
         media = self.get_current_media()
         if media is not None:
-            currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
-            self.playlist.set_value(currentTrack, self.discovery_status_field, DiscoveryStatus.FAILED)
+            if self.currentTrack and self.currentTrack.valid():
+                currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
+                self.playlist.set_value(currentTrack, self.discovery_status_field, DiscoveryStatus.FAILED)
             uri = media.get_url()
         else:
             uri = 'none'
@@ -261,8 +262,9 @@ class Player(GObject.GObject):
     @log
     def _on_glib_idle(self):
         self.currentTrack = self.nextTrack
-        self.currentTrackUri = self.playlist.get_value(
-            self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
+        if self.currentTrack and self.currentTrack.valid():
+            self.currentTrackUri = self.playlist.get_value(
+                self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
         self.play()
 
     @log
@@ -271,6 +273,8 @@ class Player(GObject.GObject):
 
     @log
     def _get_random_iter(self, currentTrack):
+        if not currentTrack or not self.playlist.iter_is_valid(currentTrack):
+            return None
         currentPath = int(self.playlist.get_path(currentTrack).to_string())
         rows = self.playlist.iter_n_children(None)
         if rows == 1:
@@ -305,9 +309,7 @@ class Player(GObject.GObject):
         elif self.repeat == RepeatType.SHUFFLE:
             if currentTrack:
                 nextTrack = self._get_random_iter(currentTrack)
-                if self.shuffleHistory.full():
-                    self.shuffleHistory.get_nowait()
-                self.shuffleHistory.put_nowait(currentTrack)
+                self.shuffleHistory.append(currentTrack)
 
         if nextTrack:
             return Gtk.TreeRowReference.new(self.playlist, self.playlist.get_path(nextTrack))
@@ -349,8 +351,15 @@ class Player(GObject.GObject):
                 previousTrack = self.playlist.iter_previous(currentTrack)
         elif self.repeat == RepeatType.SHUFFLE:
             if currentTrack:
-                if not self.shuffleHistory.empty():
-                    previousTrack = self.shuffleHistory.get_nowait()
+                if self.played_seconds < 10 and len(self.shuffleHistory) > 0:
+                    previousTrack = self.shuffleHistory.pop()
+
+                    # Discard the current song, which is already queued
+                    if self.playlist.get_path(previousTrack) == self.playlist.get_path(currentTrack):
+                        previousTrack = None
+
+                if previousTrack is None and len(self.shuffleHistory) > 0:
+                    previousTrack = self.shuffleHistory.pop()
                 else:
                     previousTrack = self._get_random_iter(currentTrack)
 
@@ -475,9 +484,10 @@ class Player(GObject.GObject):
         if url != self.player.get_value('current-uri', 0):
             self.player.set_property('uri', url)
 
-        currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
-        self.emit('playlist-item-changed', self.playlist, currentTrack)
-        self.emit('current-changed')
+        if self.currentTrack and self.currentTrack.valid():
+            currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
+            self.emit('playlist-item-changed', self.playlist, currentTrack)
+            self.emit('current-changed')
 
         self._validate_next_track()
 
@@ -571,7 +581,7 @@ class Player(GObject.GObject):
 
         self.stop()
         self.currentTrack = self.nextTrack
-        if self.currentTrack:
+        if self.currentTrack and self.currentTrack.valid():
             self.currentTrackUri = self.playlist.get_value(
                 self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
             self.play()
@@ -593,7 +603,7 @@ class Player(GObject.GObject):
         self.stop()
 
         self.currentTrack = self._get_previous_track()
-        if self.currentTrack:
+        if self.currentTrack and self.currentTrack.valid():
             self.currentTrackUri = self.playlist.get_value(
                 self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
             self.play()
@@ -620,7 +630,7 @@ class Player(GObject.GObject):
         self.playlistType = type
         self.playlistId = id
         self.currentTrack = Gtk.TreeRowReference.new(model, model.get_path(iter))
-        if self.currentTrack:
+        if self.currentTrack and self.currentTrack.valid():
             self.currentTrackUri = self.playlist.get_value(
                 self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
         self.playlistField = field
@@ -735,11 +745,13 @@ class Player(GObject.GObject):
             try:
                 percentage = self.played_seconds / self.duration
                 if not self.scrobbled and percentage > 0.4:
-                    just_played_url = self.get_current_media().get_url()
+                    current_media = self.get_current_media()
                     self.scrobbled = True
-                    playlists.update_playcount(just_played_url)
-                    playlists.update_last_played(just_played_url)
-                    playlists.update_all_static_playlists()
+                    if current_media:
+                        just_played_url = self.get_current_media().get_url()
+                        playlists.update_playcount(just_played_url)
+                        playlists.update_last_played(just_played_url)
+                        playlists.update_all_static_playlists()
             except Exception as e:
                 logger.warn("Error: %s, %s" % (e.__class__, e))
         return True
