@@ -89,7 +89,7 @@ class Window(Gtk.ApplicationWindow):
         self._setup_view()
 
         self.connect("window-state-event", self._on_window_state_event)
-        self.connect("configure-event", self._on_configure_event)
+        self.configure_event_handler = self.connect("configure-event", self._on_configure_event)
 
         self.proxy = Gio.DBusProxy.new_sync(Gio.bus_get_sync(Gio.BusType.SESSION, None),
                                             Gio.DBusProxyFlags.NONE,
@@ -131,8 +131,12 @@ class Window(Gtk.ApplicationWindow):
                 self.toolbar._select_button.set_sensitive(True)
                 self.toolbar.show_stack()
 
-    @log
     def _on_configure_event(self, widget, event):
+        with self.handler_block(self.configure_event_handler):
+            GLib.idle_add(self.store_window_size_and_position, widget, priority=GLib.PRIORITY_LOW)
+
+    @log
+    def store_window_size_and_position(self, widget):
         size = widget.get_size()
         self.settings.set_value('window-size', GLib.Variant('ai', [size[0], size[1]]))
 
@@ -307,6 +311,7 @@ class Window(Gtk.ApplicationWindow):
     @log
     def _init_loading_notification(self):
         self.notification = Gd.Notification()
+        self.notification.set_timeout(5)
         grid = Gtk.Grid(valign=Gtk.Align.CENTER, margin_right=8)
         grid.set_column_spacing(8)
         spinner = Gtk.Spinner()
